/**
 * Copyright (c) Members of the EGEE Collaboration. 2004-2010. 
 * See http://www.eu-egee.org/partners/ for details on the copyright
 * holders.  
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"); 
 * you may not use this file except in compliance with the License. 
 * You may obtain a copy of the License at 
 * 
 *     http://www.apache.org/licenses/LICENSE-2.0 
 * 
 * Unless required by applicable law or agreed to in writing, software 
 * distributed under the License is distributed on an "AS IS" BASIS, 
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
 * See the License for the specific language governing permissions and 
 * limitations under the License.
 *
 *
 *  Authors:
 *  2009-
 *     Oscar Koeroo <okoeroo@nikhef.nl>
 *     Mischa Sall\'e <msalle@nikhef.nl>
 *     David Groep <davidg@nikhef.nl>
 *     NIKHEF Amsterdam, the Netherlands
 *     <grid-mw-security@nikhef.nl> 
 *
 *  2007-2009
 *     Oscar Koeroo <okoeroo@nikhef.nl>
 *     David Groep <davidg@nikhef.nl>
 *     NIKHEF Amsterdam, the Netherlands
 *
 *  2003-2007
 *     Martijn Steenbakkers <martijn@nikhef.nl>
 *     Oscar Koeroo <okoeroo@nikhef.nl>
 *     David Groep <davidg@nikhef.nl>
 *     NIKHEF Amsterdam, the Netherlands
 *
 */


/*!
    \file   lcas_vo_data.h
    \brief  LCAS module for creating and accessing VO data structures
    \author Martijn Steenbakkers for the EU DataGrid.

    The interface is composed of:
    -# lcas_createVoData(): create a VoData structure
    -# lcas_deleteVoData(): delete a VoData structure
    -# lcas_copyVoData(): copy (the contents of) a VoData structure
    -# lcas_printVoData(): print the contents of a VoData structure
    -# lcas_stringVoData(): cast a VoData structure into a string
    \ingroup APIforLcasPlugins
*/

#ifndef LCAS_VO_DATA_H
#define LCAS_VO_DATA_H

/******************************************************************************
                             Include header files
******************************************************************************/


/******************************************************************************
                               Type definitions
******************************************************************************/

/*!
    \struct lcas_vo_data_s
    \brief structure that contains the VO information found
           in the user's gss credential
*/
/*!
    \typedef lcas_cred_id_t
    \brief Type of VO information structure
*/
typedef struct lcas_vo_data_s
{
    char * vo;         /*!< name of the VO to which the user belongs */
    char * group;      /*!< group within the VO */
    char * subgroup;   /*!< subgroup name */
    char * role;       /*!< the user's role */
    char * capability; /*!< the user's capability */
} lcas_vo_data_t;

/******************************************************************************
 *                 Module definition
 *****************************************************************************/ 

extern lcas_vo_data_t *
lcas_createVoData(
    const char * vo,
    const char * group,
    const char * subgroup,
    const char * role,
    const char * capability
);

extern int
lcas_deleteVoData(
    lcas_vo_data_t ** vo_data
);

extern int
lcas_cleanVoData(
    lcas_vo_data_t * vo_data
);

extern int
lcas_copyVoData(
    lcas_vo_data_t * dst_vo_data,
    const lcas_vo_data_t * src_vo_data
);

extern int
lcas_printVoData(
    int debug_level,
    const lcas_vo_data_t * vo_data
);

extern int
lcas_stringVoData(
    const lcas_vo_data_t * vo_data,
    char * buffer,
    int nchars
);

extern char *
lcas_parseVostring(
    char * vo_string
);

#endif /* LCAS_VO_DATA_H */

/******************************************************************************
CVS Information:
    $Source: /srv/home/dennisvd/svn/mw-security/lcas-plugins-voms/src/voms/lcas_vo_data.h,v $
    $Date: 2010-05-03 10:44:38 $
    $Revision: 1.5 $
    $Author: okoeroo $
******************************************************************************/
